@@ -1,8 +1,6 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * Copyright (C) 2003-2004 Imendio HB
- * Copyright (C) 2002-2003 Richard Hult <richard@imendio.com>
- * Copyright (C) 2002-2003 Mikael Hallendal <micke@imendio.com>
+ * Copyright (C) 2002-2004 Imendio HB
  * Copyright (C) 2003      Kevin Dougherty <gossip@kdough.net>
  *
  * This program is free software; you can redistribute it and/or
@@ -35,6 +33,8 @@
 #include <libgnomeui/libgnomeui.h>
 #include "eggtrayicon.h"
 #include "eel-ellipsizing-label.h"
+#include "gossip-disco-window.h"
+#include "gossip-disco.h"
 #include "gossip-vcard-dialog.h"
 #include "gossip-add-contact.h"
 #include "gossip-contact.h"
@@ -191,6 +191,8 @@ static void     app_account_information_cb           (GtkWidget          *widget
 						      GossipApp          *app);
 static void     app_status_messages_cb               (GtkWidget          *widget,
 						      GossipApp          *app);
+static void     app_discover_services_cb             (GtkWidget          *widget, 
+						      GossipApp          *app);
 static void     app_about_cb                         (GtkWidget          *widget,
 						      GossipApp          *app);
 static void     app_join_group_chat_cb               (GtkWidget          *widget,
@@ -406,6 +408,7 @@ app_init (GossipApp *singleton_app)
 			      "actions_send_chat_message", "activate", app_new_message_cb,
 			      "actions_add_contact", "activate", app_add_contact_cb,
 			      "actions_show_offline", "toggled", app_show_offline_cb,
+			      "actions_discover_services", "activate", app_discover_services_cb,
 			      "edit_preferences", "activate", app_preferences_cb,
 			      "edit_personal_details", "activate", app_personal_details_cb,
 			      "edit_account_information", "activate", app_account_information_cb,
@@ -427,12 +430,7 @@ app_init (GossipApp *singleton_app)
 	 * it until it's edited though, so the druid will come up again.
 	 */
 	if (!priv->account) {
-		priv->account = gossip_account_new ("Default",
-						    NULL, NULL,
-						    DEFAULT_RESOURCE,
-						    NULL,
-						    LM_CONNECTION_DEFAULT_PORT,
-						    FALSE);
+		priv->account = gossip_account_create_empty ();
 	}
 
 	app_create_connection ();
@@ -561,7 +559,7 @@ app_main_window_destroy_cb (GtkWidget *window,
 
 	connection = app->priv->connection;
 
-	if (lm_connection_get_state (connection) == LM_CONNECTION_STATE_CONNECTING) {
+	if (lm_connection_get_state (connection) == LM_CONNECTION_STATE_OPENING) {
 		lm_connection_cancel_open (connection);
 	} else if (lm_connection_is_open (connection)) {
 		lm_connection_close (connection, NULL);
@@ -663,19 +661,14 @@ app_new_message_presence_data_func (GtkCellLayout   *cell_layout,
 				    GtkTreeIter     *iter,
 				    gpointer         unused)
 {
-	GossipContact *c;
-	GdkPixbuf     *pixbuf;
-	
+	GossipContact  *c;
+	GdkPixbuf      *pixbuf;
+	GossipPresence *p;
+
 	gtk_tree_model_get (tree_model, iter, 0, &c, -1);
 
-	if (!gossip_contact_is_online (c)) {
-		pixbuf = gossip_utils_get_pixbuf_offline ();
-	} else {
-		GossipPresence *p;
-
-		p = gossip_contact_get_presence (c);
-		pixbuf = gossip_utils_get_pixbuf_from_presence (p);
-	}
+	p = gossip_contact_get_presence (c);
+	pixbuf = gossip_presence_get_pixbuf (p);
 
 	g_object_set (cell, "pixbuf", pixbuf, NULL);
 	g_object_unref (pixbuf);
@@ -920,6 +913,12 @@ app_status_messages_cb (GtkWidget *widget, GossipApp *app)
 	gossip_preferences_show_status_editor ();
 }
 
+static void
+app_discover_services_cb (GtkWidget *widget, GossipApp *app)
+{
+	gossip_disco_window_show ();
+}
+
 static void
 app_subscription_request_dialog_response_cb (GtkWidget *dialog,
 					     gint       response,
@@ -1137,7 +1136,7 @@ app_iq_handler (LmMessageHandler *handler,
 		
 		namespace = lm_message_node_get_attribute (node, "xmlns");
 		
-		if (strcmp (namespace, "jabber:iq:version") == 0) {
+		if (namespace && strcmp (namespace, "jabber:iq:version") == 0) {
 			LmMessage      *v;
 			const gchar    *from, *id;
 			struct utsname  osinfo;
@@ -1156,7 +1155,7 @@ app_iq_handler (LmMessageHandler *handler,
 			lm_message_node_set_attributes (node,
 							"xmlns", namespace,
 							NULL);
-			lm_message_node_add_child (node, "name", "Gossip");
+			lm_message_node_add_child (node, "name", "Imendio Gossip");
 			lm_message_node_add_child (node, "version", VERSION);
 			
 			uname (&osinfo);
@@ -1179,6 +1178,7 @@ app_connection_open_cb (LmConnection *connection,
 	gchar         *password;
 	GossipAccount *account;
 	const gchar   *resource = NULL;
+	gchar         *username;
 
 	priv = app->priv;
 
@@ -1208,7 +1208,7 @@ app_connection_open_cb (LmConnection *connection,
 		resource = priv->overridden_resource;
 	}
 	if (!resource || !resource[0]) {
-		resource = account->resource;
+		resource = gossip_jid_get_resource (account->jid);
 	}
 	if (!resource || !resource[0]) {
 		resource = DEFAULT_RESOURCE;
@@ -1217,15 +1217,18 @@ app_connection_open_cb (LmConnection *connection,
 	if (priv->jid) {
 		gossip_jid_unref (priv->jid);
 	}
-	priv->jid = gossip_account_get_jid (account);
 
+	priv->jid = gossip_jid_ref (account->jid);
+
+	username = gossip_jid_get_part_name (priv->jid);
+	
 	lm_connection_authenticate (connection, 
-				    account->username, 
+				    username, 
 				    password,
 				    resource,
 				    (LmResultFunction) app_authentication_cb,
 				    app, NULL, NULL);
-
+	g_free (username);
 	g_free (password);
 }
 
@@ -1387,6 +1390,9 @@ gossip_app_connect (void)
 	account = priv->account;
 	
 	lm_connection_set_server (priv->connection, account->server);
+	
+	lm_connection_set_jid (priv->connection, gossip_jid_get_without_resource (account->jid));
+
 	lm_connection_set_port (priv->connection, account->port);
 	
 	if (account->use_ssl) {
@@ -1443,12 +1449,6 @@ gossip_app_get (void)
 	return app;
 }
 
-const gchar *
-gossip_app_get_username (void)
-{
-	return app->priv->account->username;
-}
-
 GossipJID *
 gossip_app_get_jid (void)
 {
@@ -1470,6 +1470,13 @@ app_create_connection (void)
 	priv = app->priv;
 
 	priv->connection = lm_connection_new (priv->account->server);
+
+	// Setup the connection to send keep alive messages every 30 second.
+	lm_connection_set_keep_alive_rate (priv->connection, 30);
+
+	gossip_utils_set_proxy (priv->connection);
+	lm_connection_set_jid (priv->connection, gossip_jid_get_without_resource (priv->account->jid));
+
 	lm_connection_set_port (priv->connection, priv->account->port);
 
 	handler = lm_message_handler_new ((LmHandleMessageFunction) app_message_handler, 
@@ -1526,6 +1533,7 @@ app_setup_conn_dependent_menu_items (GladeXML *glade)
 		"actions_send_chat_message",
 		"actions_add_contact",
 		"status_button",
+		"actions_discover_services",
 		"edit_personal_details"
 	};
 	
