@@ -22,6 +22,7 @@
 #define __GOSSIP_PRESENCE_H__
 
 #include <glib.h>
+#include <gdk/gdkpixbuf.h>
 
 typedef struct _GossipPresence GossipPresence;
 
@@ -53,5 +54,7 @@ void                gossip_presence_set_status   (GossipPresence *presence,
 GossipPresence *    gossip_presence_ref          (GossipPresence *presence);
 void                gossip_presence_unref        (GossipPresence *presence);
 
+GdkPixbuf *         gossip_presence_get_pixbuf     (GossipPresence *presence);
+
 #endif /* __GOSSIP_PRESENCE_H__ */
 
