@@ -115,7 +115,7 @@ register_connection_open_cb (LmConnection        *connection,
 		return;
 	}
 
-	jid = gossip_account_get_jid (data->account);
+	jid = gossip_jid_ref (data->account->jid);
 	
 	msg = lm_message_new_with_sub_type (NULL,
 					    LM_MESSAGE_TYPE_IQ,
@@ -156,12 +156,14 @@ gossip_register_account (GossipAccount *account,
 		password = g_strdup (account->password);
 	}
 	
-	jid = gossip_account_get_jid (account);
+	jid = gossip_jid_ref (account->jid);
 
 	data = g_new0 (RegisterAccountData, 1);
 
 	data->account = account;
 	data->connection = lm_connection_new (account->server);
+	gossip_utils_set_proxy (data->connection);
+
 	lm_connection_set_port (data->connection, account->port);
 	if (account->use_ssl) {
 		LmSSL *ssl = lm_ssl_new (NULL,  
